-- About TrackShipping.lua
-- Author: Atlas Systems, Inc.
--
-- TrackShipping.lua checks the value of the transaction field specified by the ConstIlliadField variable. If it contains a 
-- value, it then does a very basic comparison to determine if it is a UPS or Fedex tracking number and searchings the tracking number
-- on the appropriate tracking form.
--
-- autoSearch (boolean) determines whether the search is performed automatically when a request is opened or not.
--


-- set autoSearch to true for this script to automatically run the search when the request is opened.
local autoSearch = GetSetting("AutoSearch");

local debugEnabled = false;

local interfaceMngr = nil;
local browser = nil;

-- Constants
local ConstTypeFedex = "Fedex";
local ConstTypeUps = "UPS";
local ConstTypeUsps = "USPS";

local ConstFedexAddress = "http://www.fedex.com/Tracking?cntry_code=us&tracknumbers=";
local ConstUpsAddress = "http://wwwapps.ups.com/WebTracking/track?loc=en_US&track.x=Track&trackNums=";
local ConstUspsAddress = "http://trkcnfrm1.smi.usps.com/PTSInternetWeb/InterLabelInquiry.do?trackGo.x=10&trackGo.y=7&strOrigTrackNum=";

local ConstIlliadField = GetSetting("ILLiadField");

function Init()
	if IsValidTransaction() then
		Log("TrackShipping Init");
		
		interfaceMngr = GetInterfaceManager();
		
        -- Create browser		
		browser = interfaceMngr:CreateBrowser("Shipments", "Shipments", "Script");
        
        -- Create buttons
        browser:CreateButton("Search", GetClientImage("Search32"), "Search", "Tracking Number");
		
        browser:Show();
        
		-- Search when opened if autoSearch is true
		if autoSearch  then
			Search();
		end
	end
end

function Search()
	Log("Search");
	local trackingType = GetTrackingNumberType(GetFieldValue("Transaction", ConstIlliadField));
	
	Log("Tracking Type = " .. trackingType);
	
	if trackingType == ConstTypeUps then
		browser:Navigate(ConstUpsAddress .. GetFieldValue("Transaction", ConstIlliadField));	
	elseif trackingType == ConstTypeFedex then
		browser:Navigate(ConstFedexAddress .. GetFieldValue("Transaction", ConstIlliadField));	
	elseif trackingType == ConstTypeUsps then
		browser:Navigate(ConstUspsAddress .. GetFieldValue("Transaction", ConstIlliadField));
	end;
end

function IsValidTransaction()
	Log("IsValidTransaction()");
	
	return (GetFieldValue("Transaction", "ProcessType") == "Lending" 
					  and GetFieldValue("Transaction", "TransactionStatus") == "Item Shipped");
end

function GetTrackingNumberType(trackingNumString)
	Log("Getting Tracking Number Type");
	
	trackingNumString = trackingNumString:gsub(" ", "");
	
	if debugEnabled then
		Log("Tracking Number Length = " .. string.len(trackingNumString));
	end
	local trackingType = nil;
	
	if string.len(trackingNumString) == 0 then
		trackingType = "UNKNOWN";
	elseif string.len(trackingNumString) < 18 then	
		trackingType = ConstTypeFedex;
	elseif string.len(trackingNumString) < 20 then
		trackingType = ConstTypeUps;
	else
		trackingType = ConstTypeUsps;
	end
	
	Log("Returning " .. trackingType .. " from GetTrackingNumberType");
	
	return trackingType;
end

function Log(entry)
	if debugEnabled then
		LogDebug("----- " .. entry .. " -----");
	end
end

